<?php

namespace App\Http\Controllers;

use App\Models\GuestGroup;
use Illuminate\Http\Request;
use App\Models\Guest;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Mail;
use App\Mail\RsvpConfirmation;

class RsvpController extends Controller
{
    function index()
    {
        return view('rsvp');
    }

    function searchRsvpPin(Request $request)
    {
        $guestGroup = GuestGroup::where('pin', 'like', '%' . $request->search . '%')->first();
        
        if ($guestGroup) {
            $guests = $guestGroup->guests; 
            return view('components/rsvp/edit', ['guests' => $guests, 'guestGroup' => $guestGroup]);
        } else {
            return view('components/rsvp/no-matching-group');
        }        
    }

    public function saveAllGuests(Request $request, Guest $guest, GuestGroup $guestGroup) {

        // Validate the incoming request data
        $validatedData = $request->validate([
            'guests' => 'required|array',
            'guests.*.id' => 'required|integer',
            'guests.*.guest_name' => 'required|string|max:255',
            'guests.*.is_attending' => 'required|boolean',
            'guests.*.diet' => 'nullable|string|max:255',
            'guests.*.allergies' => 'nullable|string|max:255',
        ]);          

        // Update each guest's information
        foreach ($validatedData['guests'] as $guestData) {            
            Guest::upsert($guestData, ['id']);
        }

        // Extract the guest group email from the request

        $guestGroupId = $request->input('guestGroupID');
        $guestGroupEmail = $request->input('guestGroupEmail');

        if ($guestGroupId && $guestGroupEmail) {
            // Update the guest group email
            $guestGroup->where('id', $guestGroupId)->update(['email' => $guestGroupEmail]);
        }

        // Prepare the email data
        $emailData = [
            'guestGroup' => $guestGroup,
            'guests' => $validatedData['guests']
        ];

        // Send email to the user
        Mail::to($guestGroupEmail)->send(new \App\Mail\RsvpConfirmation($emailData));

        // Send email to the admin
        // Mail::to('admin@example.com')->send(new \App\Mail\RsvpConfirmation($emailData));
        
        return redirect()->route('confirmation-thanks')->with('success', 'Rspv sent');
    }
}
