<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('guest_groups', function (Blueprint $table) {
            $table->id();
            $table->string('pin', 6)->unique(); // PIN for user lookup
            $table->string('email')->unique(); // Email address of the guest group
            $table->enum('invitation_type', ['Allday', 'Evening'])->default('Evening'); // Type of invitation
            $table->timestamps();
        });

        Schema::create('guests', function (Blueprint $table) {
            $table->id(); // Primary key
            $table->foreignId('guest_group_id')->constrained('guest_groups')->onDelete('cascade');
            $table->string('guest_name')->nullable(); // Name of the guest
            $table->boolean('is_attending')->default(false); // Attendance status, defaults to "no"
            $table->enum('diet', ['None', 'Vegetarian', 'Vegan'])->nullable(); // Diet preferences
            $table->text('allergies')->nullable(); // Food allergies
            $table->timestamps();
        });        
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('guests');
    }
};
